Index: /trunk/src/VBox/VMM/CPUM.cpp
===================================================================
--- /trunk/src/VBox/VMM/CPUM.cpp	(revision 463)
+++ /trunk/src/VBox/VMM/CPUM.cpp	(revision 464)
@@ -125,11 +125,11 @@
         Log(("The CPU doesn't support FXSAVE/FXRSTOR!\n"));
         /* No FXSAVE implies no SSE */
-        pVM->cpum.s.CR4.Mask   = X86_CR4_PVI | X86_CR4_VME;
-        pVM->cpum.s.CR4.OSFSXR = 0;
+        pVM->cpum.s.CR4.AndMask = X86_CR4_PVI | X86_CR4_VME;
+        pVM->cpum.s.CR4.OrMask  = 0;
     }
     else
     {
-        pVM->cpum.s.CR4.Mask   = X86_CR4_OSXMMEEXCPT | X86_CR4_PVI | X86_CR4_VME;
-        pVM->cpum.s.CR4.OSFSXR = X86_CR4_OSFSXR;
+        pVM->cpum.s.CR4.AndMask = X86_CR4_OSXMMEEXCPT | X86_CR4_PVI | X86_CR4_VME;
+        pVM->cpum.s.CR4.OrMask  = X86_CR4_OSFSXR;
     }
 
Index: /trunk/src/VBox/VMM/CPUMInternal.h
===================================================================
--- /trunk/src/VBox/VMM/CPUMInternal.h	(revision 463)
+++ /trunk/src/VBox/VMM/CPUMInternal.h	(revision 464)
@@ -317,6 +317,6 @@
     struct
     {
-        uint32_t Mask;
-        uint32_t OSFSXR;
+        uint32_t AndMask;
+        uint32_t OrMask;
     } CR4;
 
Index: /trunk/src/VBox/VMM/CPUMInternal.mac
===================================================================
--- /trunk/src/VBox/VMM/CPUMInternal.mac	(revision 463)
+++ /trunk/src/VBox/VMM/CPUMInternal.mac	(revision 464)
@@ -377,6 +377,6 @@
     .CPUFeatures.ecx      resd    1
     ; CR4 masks
-    .CR4.Mask             resd    1
-    .CR4.OSFSXR           resd    1
+    .CR4.AndMask          resd    1
+    .CR4.OrMask           resd    1
     ; entered rawmode?
     .fRawEntered          resb    1
Index: /trunk/src/VBox/VMM/VMMSwitcher/PAEand32Bit.mac
===================================================================
--- /trunk/src/VBox/VMM/VMMSwitcher/PAEand32Bit.mac	(revision 463)
+++ /trunk/src/VBox/VMM/VMMSwitcher/PAEand32Bit.mac	(revision 464)
@@ -193,10 +193,10 @@
 
     ;
-    ; CR4.Mask and CR4.OSFSXR are set in CPUMR3Init based on the presence of
+    ; CR4.AndMask and CR4.OrMask are set in CPUMR3Init based on the presence of
     ; FXSAVE support on the host CPU
     ;
-    and     ecx, [edx + CPUM.CR4.Mask]
+    and     ecx, [edx + CPUM.CR4.AndMask]
     or      eax, ecx
-    or      eax, [edx + CPUM.CR4.OSFSXR]
+    or      eax, [edx + CPUM.CR4.OrMask]
     mov     cr4, eax
 

Index: /trunk/src/VBox/VMM/VMMSwitcher/AMD64ToPAE.asm
===================================================================
--- /trunk/src/VBox/VMM/VMMSwitcher/AMD64ToPAE.asm	(revision 463)
+++ /trunk/src/VBox/VMM/VMMSwitcher/AMD64ToPAE.asm	(revision 464)
@@ -230,10 +230,10 @@
 
     ;
     ; CR4.Mask and CR4.OSFSXR are set in CPUMR3Init based on the presence of
     ; FXSAVE support on the host CPU
     ;
-    and     ecx, [rdx + CPUM.CR4.Mask]
+    and     ecx, [rdx + CPUM.CR4.AndMask]
     or      eax, ecx
-    or      eax, [rdx + CPUM.CR4.OSFSXR]
+    or      eax, [rdx + CPUM.CR4.OrMask]
     mov     cr4, rax
     DEBUG_CHAR('c')                     ; trashes esi
@@ -230,10 +230,10 @@
 
     ;
-    ; CR4.Mask and CR4.OSFSXR are set in CPUMR3Init based on the presence of
+    ; CR4.AndMask and CR4.OrMask are set in CPUMR3Init based on the presence of
     ; FXSAVE support on the host CPU
     ;